/*
 * Part of FSView.
 * Example for usage of the treemap widget.
 *
 * (C) 2002, Josef Weidendorfer
 */

#ifndef FSVIEW_H
#define FSVIEW_H

#include <qmap.h>
#include <qptrlist.h>
#include <qfileinfo.h>
#include <qstring.h>
#include "treemap.h"

/**
 * A specialized version of a TreeMapItem
 * for representation of an Inode.
 *
 * This includes a QFileInfo object and a size including
 * all subdirs.
 */
class Inode: public TreeMapItem
{
public:
  Inode(QString);
  unsigned int value();
  void update();
  void setPath(QString);
  QString path();
  QString text(int i);
  QColor color();

private:
  void init(QString);
  void finishUpdate();
  void gotChildSize(unsigned int, unsigned int);

  QFileInfo _info;
  unsigned int _size, _sizeEstimation;
  unsigned int _files, _filesEstimation;
  int _subDirsUnknown;
};

/**
 * The root object for the treemap.
 *
 * Does context menu handling and
 * asynchronous file size update
 */
class FSView : public TreeMapWidget
{
  Q_OBJECT
public:
  FSView();
  void setPath(QString);
  QString path() { return _path; }
  int pathDepth() { return _pathDepth; }
  void requestUpdate(Inode*);

  static bool getDirMetric(QString, unsigned int&, unsigned int&);
  static void setDirMetric(QString, unsigned int, unsigned int);

public slots:
  void selected(TreeMapItem*);
  void contextMenu(TreeMapItem*, const QPoint &);
  void quit();
  void doUpdate();

private:

  // list of Inode objects (directories) with still unknown content
  QPtrList<Inode> _needsUpdate;
  // when a contextMenu is shown, we don't allow async. refreshs
  bool _allowRefresh;
  // a cache for directory sizes with long lasting updates
  static QMap<QString, QPair<unsigned int, unsigned int> > _dirMetric;

  // current root path
  int _pathDepth;
  QString _path;
};

#endif // FSVIEW_H

