/*****************************************************
 * FSView, a simple TreeMap application
 *
 * (C) 2002, Josef Weidendorfer
 */

#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <kglobal.h>
#include <kconfig.h>

#include "fsview.h"


static KCmdLineOptions options[] =
{
  { "+[dir]", I18N_NOOP("View filesystem starting from this directory"), 0 },
  { 0, 0, 0 } // End of options.
};

int main(int argc, char* argv[])
{
  // KDE compliant startup
  KAboutData aboutData("fsview", I18N_NOOP("FSView"), "0.1",
                       I18N_NOOP("Filesystem Viewer"),
                       KAboutData::License_GPL,
                       I18N_NOOP("(c) 2002, Josef Weidendorfer"));
  KCmdLineArgs::init(argc, argv, &aboutData);
  KCmdLineArgs::addCmdLineOptions(options);
  KApplication a;

  KConfigGroup gconfig(KGlobal::config(), QCString("General"));
  QString path = gconfig.readEntry("Path", ".");

  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
  if (args->count()>0) path = args->arg(0);

  // TreeMap Widget as toplevel window
  FSView w;
  w.setVisibleWidth(4, true);
  w.setTextType(0, "Name");
  w.setTextType(1, "Size");
  w.setTextType(2, "File Count");
  w.setTextType(3, "Last Modified");
  w.setTextType(4, "Owner");
  w.setTextType(5, "Group");
  w.setSplitMode(TreeMapItem::Bisection);

  QObject::connect(&w,SIGNAL(selectionChanged(TreeMapItem*)),
                   &w,SLOT(selected(TreeMapItem*)));
  QObject::connect(&w,
                   SIGNAL(contextMenuRequested(TreeMapItem*,const QPoint&)),
                   &w,SLOT(contextMenu(TreeMapItem*, const QPoint&)));

  w.addItem(new Inode(path));
  w.setPath(path);
  w.show();

  a.connect( &a, SIGNAL( lastWindowClosed() ), &w, SLOT( quit() ) );
  return a.exec();
}
